# This file was auto-generated by Fern from our API Definition.

from ...core.client_wrapper import SyncClientWrapper
import typing
from ...types.units import Units
from ...core.request_options import RequestOptions
from ...core.http_response import HttpResponse
from ...types.daily_weather_response import DailyWeatherResponse
from ...core.pydantic_utilities import parse_obj_as
from ...errors.unprocessable_entity_error import UnprocessableEntityError
from ...types.http_validation_error import HttpValidationError
from json.decoder import JSONDecodeError
from ...core.api_error import ApiError
from ...types.timezone import Timezone
from ...types.hourly_weather_response import HourlyWeatherResponse
from ...core.client_wrapper import AsyncClientWrapper
from ...core.http_response import AsyncHttpResponse


class RawForecastClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def daily(
        self,
        *,
        latitude: float,
        longitude: float,
        timezone: typing.Optional[typing.Literal["local"]] = None,
        units: typing.Optional[Units] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[DailyWeatherResponse]:
        """
        Get daily weather forecast for a specific location
        Only allowing local timezone aggregations for now since
        it is unclear how exactly users will understand "UTC".

        Parameters
        ----------
        latitude : float

        longitude : float

        timezone : typing.Optional[typing.Literal["local"]]

        units : typing.Optional[Units]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[DailyWeatherResponse]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            "forecast/daily",
            method="GET",
            params={
                "latitude": latitude,
                "longitude": longitude,
                "timezone": timezone,
                "units": units,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    DailyWeatherResponse,
                    parse_obj_as(
                        type_=DailyWeatherResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def hourly(
        self,
        *,
        latitude: float,
        longitude: float,
        timezone: typing.Optional[Timezone] = None,
        units: typing.Optional[Units] = None,
        include_past: typing.Optional[bool] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[HourlyWeatherResponse]:
        """
        Get hourly weather forecast for a specific location

        Parameters
        ----------
        latitude : float

        longitude : float

        timezone : typing.Optional[Timezone]

        units : typing.Optional[Units]

        include_past : typing.Optional[bool]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[HourlyWeatherResponse]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            "forecast/hourly",
            method="GET",
            params={
                "latitude": latitude,
                "longitude": longitude,
                "timezone": timezone,
                "units": units,
                "include_past": include_past,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    HourlyWeatherResponse,
                    parse_obj_as(
                        type_=HourlyWeatherResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)


class AsyncRawForecastClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def daily(
        self,
        *,
        latitude: float,
        longitude: float,
        timezone: typing.Optional[typing.Literal["local"]] = None,
        units: typing.Optional[Units] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[DailyWeatherResponse]:
        """
        Get daily weather forecast for a specific location
        Only allowing local timezone aggregations for now since
        it is unclear how exactly users will understand "UTC".

        Parameters
        ----------
        latitude : float

        longitude : float

        timezone : typing.Optional[typing.Literal["local"]]

        units : typing.Optional[Units]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[DailyWeatherResponse]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            "forecast/daily",
            method="GET",
            params={
                "latitude": latitude,
                "longitude": longitude,
                "timezone": timezone,
                "units": units,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    DailyWeatherResponse,
                    parse_obj_as(
                        type_=DailyWeatherResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def hourly(
        self,
        *,
        latitude: float,
        longitude: float,
        timezone: typing.Optional[Timezone] = None,
        units: typing.Optional[Units] = None,
        include_past: typing.Optional[bool] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[HourlyWeatherResponse]:
        """
        Get hourly weather forecast for a specific location

        Parameters
        ----------
        latitude : float

        longitude : float

        timezone : typing.Optional[Timezone]

        units : typing.Optional[Units]

        include_past : typing.Optional[bool]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[HourlyWeatherResponse]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            "forecast/hourly",
            method="GET",
            params={
                "latitude": latitude,
                "longitude": longitude,
                "timezone": timezone,
                "units": units,
                "include_past": include_past,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    HourlyWeatherResponse,
                    parse_obj_as(
                        type_=HourlyWeatherResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)



# This file was auto-generated by Fern from our API Definition.

from typing import Dict, Generic, TypeVar

import httpx

T = TypeVar("T")


class HttpResponse(Generic[T]):
    _response: httpx.Response
    _data: T

    def __init__(self, response: httpx.Response, data: T):
        self._response = response
        self._data = data

    @property
    def headers(self) -> Dict[str, str]:
        return dict(self._response.headers)

    @property
    def data(self) -> T:
        return self._data

    def close(self) -> None:
        self._response.close()


class AsyncHttpResponse(Generic[T]):
    _response: httpx.Response
    _data: T

    def __init__(self, response: httpx.Response, data: T):
        self._response = response
        self._data = data

    @property
    def headers(self) -> Dict[str, str]:
        return dict(self._response.headers)

    @property
    def data(self) -> T:
        return self._data

    async def close(self) -> None:
        await self._response.aclose()



# This file was auto-generated by Fern from our API Definition.

from ..core.pydantic_utilities import UniversalBaseModel
import datetime as dt
import typing
from .gftus_base_units import GftusBaseUnits
from .gftus_hourly_conditions import GftusHourlyConditions
from ..core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class GftusHourlyWeatherResponse(UniversalBaseModel):
    latitude: float
    longitude: float
    forecast_time: dt.datetime
    timezone: str
    utc_offset: int
    elevation: typing.Optional[int] = None
    units: GftusBaseUnits
    hourly: typing.List[GftusHourlyConditions]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ....core.client_wrapper import SyncClientWrapper
from .raw_client import RawRegionalClient
import typing
from ....types.timezone import Timezone
from ....types.units import Units
from ....core.request_options import RequestOptions
from ....types.gftus_hourly_weather_response import GftusHourlyWeatherResponse
from ....core.client_wrapper import AsyncClientWrapper
from .raw_client import AsyncRawRegionalClient


class RegionalClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawRegionalClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawRegionalClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawRegionalClient
        """
        return self._raw_client

    def usa(
        self,
        *,
        latitude: float,
        longitude: float,
        timezone: typing.Optional[Timezone] = None,
        units: typing.Optional[Units] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> GftusHourlyWeatherResponse:
        """
        Get hourly weather forecast for a specific location and time

        Parameters
        ----------
        latitude : float

        longitude : float

        timezone : typing.Optional[Timezone]

        units : typing.Optional[Units]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        GftusHourlyWeatherResponse
            Successful Response

        Examples
        --------
        from silurian import Earth

        client = Earth(
            api_key="YOUR_API_KEY",
        )
        client.weather.experimental.regional.usa(
            latitude=47.6061,
            longitude=-122.3328,
        )
        """
        response = self._raw_client.usa(
            latitude=latitude, longitude=longitude, timezone=timezone, units=units, request_options=request_options
        )
        return response.data


class AsyncRegionalClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawRegionalClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawRegionalClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawRegionalClient
        """
        return self._raw_client

    async def usa(
        self,
        *,
        latitude: float,
        longitude: float,
        timezone: typing.Optional[Timezone] = None,
        units: typing.Optional[Units] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> GftusHourlyWeatherResponse:
        """
        Get hourly weather forecast for a specific location and time

        Parameters
        ----------
        latitude : float

        longitude : float

        timezone : typing.Optional[Timezone]

        units : typing.Optional[Units]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        GftusHourlyWeatherResponse
            Successful Response

        Examples
        --------
        import asyncio

        from silurian import AsyncEarth

        client = AsyncEarth(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.weather.experimental.regional.usa(
                latitude=47.6061,
                longitude=-122.3328,
            )


        asyncio.run(main())
        """
        response = await self._raw_client.usa(
            latitude=latitude, longitude=longitude, timezone=timezone, units=units, request_options=request_options
        )
        return response.data



# This file was auto-generated by Fern from our API Definition.

from .types import (
    BaseModel,
    CycloneForecastResponse,
    DailyConditions,
    DailyWeatherResponse,
    DailyWeatherResponseUnits,
    Feature,
    FeatureCollection,
    FeatureGeometry,
    FeatureGeometry_GeometryCollection,
    FeatureGeometry_LineString,
    FeatureGeometry_MultiLineString,
    FeatureGeometry_MultiPoint,
    FeatureGeometry_MultiPolygon,
    FeatureGeometry_Point,
    FeatureGeometry_Polygon,
    FeatureId,
    FeatureProperties,
    GeoLocation,
    GeometryCollection,
    GeometryCollectionGeometriesItem,
    GeometryCollectionGeometriesItem_GeometryCollection,
    GeometryCollectionGeometriesItem_LineString,
    GeometryCollectionGeometriesItem_MultiLineString,
    GeometryCollectionGeometriesItem_MultiPoint,
    GeometryCollectionGeometriesItem_MultiPolygon,
    GeometryCollectionGeometriesItem_Point,
    GeometryCollectionGeometriesItem_Polygon,
    GftusBaseUnits,
    GftusHourlyConditions,
    GftusHourlyWeatherResponse,
    HourlyConditions,
    HourlyWeatherResponse,
    HourlyWeatherResponseUnits,
    HttpValidationError,
    ImperialUnits,
    LineString,
    LineStringCoordinatesItem,
    MetricUnits,
    ModelName,
    MultiLineString,
    MultiLineStringCoordinatesItemItem,
    MultiPoint,
    MultiPointCoordinatesItem,
    MultiPolygon,
    MultiPolygonCoordinatesItemItemItem,
    Point,
    PointCoordinates,
    Polygon,
    PolygonCoordinatesItemItem,
    Position2D,
    Position3D,
    PrecipitationType,
    Timezone,
    Units,
    ValidationError,
    ValidationErrorLocItem,
    WeatherCode,
)
from .errors import UnprocessableEntityError
from . import cyclone, weather
from .client import AsyncEarth, Earth
from .environment import EarthEnvironment
from .version import __version__

__all__ = [
    "AsyncEarth",
    "BaseModel",
    "CycloneForecastResponse",
    "DailyConditions",
    "DailyWeatherResponse",
    "DailyWeatherResponseUnits",
    "Earth",
    "EarthEnvironment",
    "Feature",
    "FeatureCollection",
    "FeatureGeometry",
    "FeatureGeometry_GeometryCollection",
    "FeatureGeometry_LineString",
    "FeatureGeometry_MultiLineString",
    "FeatureGeometry_MultiPoint",
    "FeatureGeometry_MultiPolygon",
    "FeatureGeometry_Point",
    "FeatureGeometry_Polygon",
    "FeatureId",
    "FeatureProperties",
    "GeoLocation",
    "GeometryCollection",
    "GeometryCollectionGeometriesItem",
    "GeometryCollectionGeometriesItem_GeometryCollection",
    "GeometryCollectionGeometriesItem_LineString",
    "GeometryCollectionGeometriesItem_MultiLineString",
    "GeometryCollectionGeometriesItem_MultiPoint",
    "GeometryCollectionGeometriesItem_MultiPolygon",
    "GeometryCollectionGeometriesItem_Point",
    "GeometryCollectionGeometriesItem_Polygon",
    "GftusBaseUnits",
    "GftusHourlyConditions",
    "GftusHourlyWeatherResponse",
    "HourlyConditions",
    "HourlyWeatherResponse",
    "HourlyWeatherResponseUnits",
    "HttpValidationError",
    "ImperialUnits",
    "LineString",
    "LineStringCoordinatesItem",
    "MetricUnits",
    "ModelName",
    "MultiLineString",
    "MultiLineStringCoordinatesItemItem",
    "MultiPoint",
    "MultiPointCoordinatesItem",
    "MultiPolygon",
    "MultiPolygonCoordinatesItemItemItem",
    "Point",
    "PointCoordinates",
    "Polygon",
    "PolygonCoordinatesItemItem",
    "Position2D",
    "Position3D",
    "PrecipitationType",
    "Timezone",
    "Units",
    "UnprocessableEntityError",
    "ValidationError",
    "ValidationErrorLocItem",
    "WeatherCode",
    "__version__",
    "cyclone",
    "weather",
]



# This file was auto-generated by Fern from our API Definition.

from ...core.client_wrapper import SyncClientWrapper
from .raw_client import RawPastClient
from .forecast.client import ForecastClient
from ...core.client_wrapper import AsyncClientWrapper
from .raw_client import AsyncRawPastClient
from .forecast.client import AsyncForecastClient


class PastClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawPastClient(client_wrapper=client_wrapper)
        self.forecast = ForecastClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawPastClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawPastClient
        """
        return self._raw_client


class AsyncPastClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawPastClient(client_wrapper=client_wrapper)
        self.forecast = AsyncForecastClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawPastClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawPastClient
        """
        return self._raw_client



# This file was auto-generated by Fern from our API Definition.

import typing
from .base_model import BaseModel

FeatureProperties = typing.Union[typing.Dict[str, typing.Optional[typing.Any]], BaseModel]



# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations
from ..core.pydantic_utilities import UniversalBaseModel
import typing
from ..core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic
from .line_string_coordinates_item import LineStringCoordinatesItem
from .multi_line_string_coordinates_item_item import MultiLineStringCoordinatesItemItem
from .multi_point_coordinates_item import MultiPointCoordinatesItem
from .multi_polygon_coordinates_item_item_item import MultiPolygonCoordinatesItemItemItem
from .point_coordinates import PointCoordinates
from .polygon_coordinates_item_item import PolygonCoordinatesItemItem
from ..core.pydantic_utilities import update_forward_refs


class GeometryCollectionGeometriesItem_GeometryCollection(UniversalBaseModel):
    type: typing.Literal["GeometryCollection"] = "GeometryCollection"
    bbox: typing.Optional[typing.List[typing.Optional[typing.Any]]] = None
    geometries: typing.List["GeometryCollectionGeometriesItem"]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


from .geometry_collection import GeometryCollection  # noqa: E402


class GeometryCollectionGeometriesItem_LineString(UniversalBaseModel):
    type: typing.Literal["LineString"] = "LineString"
    bbox: typing.Optional[typing.List[typing.Optional[typing.Any]]] = None
    coordinates: typing.List[LineStringCoordinatesItem]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class GeometryCollectionGeometriesItem_MultiLineString(UniversalBaseModel):
    type: typing.Literal["MultiLineString"] = "MultiLineString"
    bbox: typing.Optional[typing.List[typing.Optional[typing.Any]]] = None
    coordinates: typing.List[typing.List[MultiLineStringCoordinatesItemItem]]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class GeometryCollectionGeometriesItem_MultiPoint(UniversalBaseModel):
    type: typing.Literal["MultiPoint"] = "MultiPoint"
    bbox: typing.Optional[typing.List[typing.Optional[typing.Any]]] = None
    coordinates: typing.List[MultiPointCoordinatesItem]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class GeometryCollectionGeometriesItem_MultiPolygon(UniversalBaseModel):
    type: typing.Literal["MultiPolygon"] = "MultiPolygon"
    bbox: typing.Optional[typing.List[typing.Optional[typing.Any]]] = None
    coordinates: typing.List[typing.List[typing.List[MultiPolygonCoordinatesItemItemItem]]]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class GeometryCollectionGeometriesItem_Point(UniversalBaseModel):
    type: typing.Literal["Point"] = "Point"
    bbox: typing.Optional[typing.List[typing.Optional[typing.Any]]] = None
    coordinates: PointCoordinates

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class GeometryCollectionGeometriesItem_Polygon(UniversalBaseModel):
    type: typing.Literal["Polygon"] = "Polygon"
    bbox: typing.Optional[typing.List[typing.Optional[typing.Any]]] = None
    coordinates: typing.List[typing.List[PolygonCoordinatesItemItem]]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


GeometryCollectionGeometriesItem = typing.Union[
    GeometryCollectionGeometriesItem_GeometryCollection,
    GeometryCollectionGeometriesItem_LineString,
    GeometryCollectionGeometriesItem_MultiLineString,
    GeometryCollectionGeometriesItem_MultiPoint,
    GeometryCollectionGeometriesItem_MultiPolygon,
    GeometryCollectionGeometriesItem_Point,
    GeometryCollectionGeometriesItem_Polygon,
]
update_forward_refs(GeometryCollectionGeometriesItem_GeometryCollection)



# This file was auto-generated by Fern from our API Definition.

from ..core.client_wrapper import SyncClientWrapper
from .raw_client import RawCycloneClient
import typing
import datetime as dt
from ..types.model_name import ModelName
from ..core.request_options import RequestOptions
from ..types.cyclone_forecast_response import CycloneForecastResponse
from ..types.feature_collection import FeatureCollection
from ..core.client_wrapper import AsyncClientWrapper
from .raw_client import AsyncRawCycloneClient


class CycloneClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawCycloneClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawCycloneClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawCycloneClient
        """
        return self._raw_client

    def query_forecasts(
        self,
        *,
        time: typing.Optional[dt.datetime] = None,
        min_storm_category: typing.Optional[int] = None,
        model: typing.Optional[ModelName] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> typing.List[CycloneForecastResponse]:
        """
        Query the available cyclone forecasts for a particular time

        Parameters
        ----------
        time : typing.Optional[dt.datetime]
            *Default value: (current time) - Default time zone: UTC*

        min_storm_category : typing.Optional[int]

        model : typing.Optional[ModelName]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.List[CycloneForecastResponse]
            Successful Response

        Examples
        --------
        from silurian import Earth

        client = Earth(
            api_key="YOUR_API_KEY",
        )
        client.cyclone.query_forecasts()
        """
        response = self._raw_client.query_forecasts(
            time=time, min_storm_category=min_storm_category, model=model, request_options=request_options
        )
        return response.data

    def get_forecast_track(
        self,
        storm_id: str,
        *,
        time: typing.Optional[dt.datetime] = None,
        model: typing.Optional[ModelName] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> FeatureCollection:
        """
        Get cyclone tracks in GeoJSON (MF-GeoJSON) format

        Parameters
        ----------
        storm_id : str

        time : typing.Optional[dt.datetime]
            *Default value: (current time) - Default time zone: UTC*

        model : typing.Optional[ModelName]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        FeatureCollection
            Successful Response

        Examples
        --------
        from silurian import Earth

        client = Earth(
            api_key="YOUR_API_KEY",
        )
        client.cyclone.get_forecast_track(
            storm_id="storm_id",
        )
        """
        response = self._raw_client.get_forecast_track(
            storm_id, time=time, model=model, request_options=request_options
        )
        return response.data

    def get_forecast_cone(
        self,
        storm_id: str,
        *,
        time: typing.Optional[dt.datetime] = None,
        lead_time: typing.Optional[str] = None,
        smooth_cone: typing.Optional[bool] = None,
        model: typing.Optional[ModelName] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> FeatureCollection:
        """
        Get cyclone forecast cone in GeoJSON format

        Parameters
        ----------
        storm_id : str

        time : typing.Optional[dt.datetime]
            *Default value: (current time) - Default time zone: UTC*

        lead_time : typing.Optional[str]

        smooth_cone : typing.Optional[bool]

        model : typing.Optional[ModelName]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        FeatureCollection
            Successful Response

        Examples
        --------
        from silurian import Earth

        client = Earth(
            api_key="YOUR_API_KEY",
        )
        client.cyclone.get_forecast_cone(
            storm_id="storm_id",
        )
        """
        response = self._raw_client.get_forecast_cone(
            storm_id,
            time=time,
            lead_time=lead_time,
            smooth_cone=smooth_cone,
            model=model,
            request_options=request_options,
        )
        return response.data


class AsyncCycloneClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawCycloneClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawCycloneClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawCycloneClient
        """
        return self._raw_client

    async def query_forecasts(
        self,
        *,
        time: typing.Optional[dt.datetime] = None,
        min_storm_category: typing.Optional[int] = None,
        model: typing.Optional[ModelName] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> typing.List[CycloneForecastResponse]:
        """
        Query the available cyclone forecasts for a particular time

        Parameters
        ----------
        time : typing.Optional[dt.datetime]
            *Default value: (current time) - Default time zone: UTC*

        min_storm_category : typing.Optional[int]

        model : typing.Optional[ModelName]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.List[CycloneForecastResponse]
            Successful Response

        Examples
        --------
        import asyncio

        from silurian import AsyncEarth

        client = AsyncEarth(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.cyclone.query_forecasts()


        asyncio.run(main())
        """
        response = await self._raw_client.query_forecasts(
            time=time, min_storm_category=min_storm_category, model=model, request_options=request_options
        )
        return response.data

    async def get_forecast_track(
        self,
        storm_id: str,
        *,
        time: typing.Optional[dt.datetime] = None,
        model: typing.Optional[ModelName] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> FeatureCollection:
        """
        Get cyclone tracks in GeoJSON (MF-GeoJSON) format

        Parameters
        ----------
        storm_id : str

        time : typing.Optional[dt.datetime]
            *Default value: (current time) - Default time zone: UTC*

        model : typing.Optional[ModelName]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        FeatureCollection
            Successful Response

        Examples
        --------
        import asyncio

        from silurian import AsyncEarth

        client = AsyncEarth(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.cyclone.get_forecast_track(
                storm_id="storm_id",
            )


        asyncio.run(main())
        """
        response = await self._raw_client.get_forecast_track(
            storm_id, time=time, model=model, request_options=request_options
        )
        return response.data

    async def get_forecast_cone(
        self,
        storm_id: str,
        *,
        time: typing.Optional[dt.datetime] = None,
        lead_time: typing.Optional[str] = None,
        smooth_cone: typing.Optional[bool] = None,
        model: typing.Optional[ModelName] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> FeatureCollection:
        """
        Get cyclone forecast cone in GeoJSON format

        Parameters
        ----------
        storm_id : str

        time : typing.Optional[dt.datetime]
            *Default value: (current time) - Default time zone: UTC*

        lead_time : typing.Optional[str]

        smooth_cone : typing.Optional[bool]

        model : typing.Optional[ModelName]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        FeatureCollection
            Successful Response

        Examples
        --------
        import asyncio

        from silurian import AsyncEarth

        client = AsyncEarth(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.cyclone.get_forecast_cone(
                storm_id="storm_id",
            )


        asyncio.run(main())
        """
        response = await self._raw_client.get_forecast_cone(
            storm_id,
            time=time,
            lead_time=lead_time,
            smooth_cone=smooth_cone,
            model=model,
            request_options=request_options,
        )
        return response.data



# This file was auto-generated by Fern from our API Definition.

import typing
from .position_2_d import Position2D
from .position_3_d import Position3D

MultiPointCoordinatesItem = typing.Union[Position2D, Position3D]



# This file was auto-generated by Fern from our API Definition.

from ...core.client_wrapper import SyncClientWrapper
from .raw_client import RawExperimentalClient
from .regional.client import RegionalClient
import typing
from ...types.timezone import Timezone
from ...types.units import Units
from ...core.request_options import RequestOptions
from ...types.hourly_weather_response import HourlyWeatherResponse
from ...core.client_wrapper import AsyncClientWrapper
from .raw_client import AsyncRawExperimentalClient
from .regional.client import AsyncRegionalClient


class ExperimentalClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawExperimentalClient(client_wrapper=client_wrapper)
        self.regional = RegionalClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawExperimentalClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawExperimentalClient
        """
        return self._raw_client

    def extended(
        self,
        *,
        latitude: float,
        longitude: float,
        timezone: typing.Optional[Timezone] = None,
        units: typing.Optional[Units] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HourlyWeatherResponse:
        """
        Get hourly weather forecast for a specific location and time

        Parameters
        ----------
        latitude : float

        longitude : float

        timezone : typing.Optional[Timezone]

        units : typing.Optional[Units]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HourlyWeatherResponse
            Successful Response

        Examples
        --------
        from silurian import Earth

        client = Earth(
            api_key="YOUR_API_KEY",
        )
        client.weather.experimental.extended(
            latitude=47.6061,
            longitude=-122.3328,
        )
        """
        response = self._raw_client.extended(
            latitude=latitude, longitude=longitude, timezone=timezone, units=units, request_options=request_options
        )
        return response.data


class AsyncExperimentalClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawExperimentalClient(client_wrapper=client_wrapper)
        self.regional = AsyncRegionalClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawExperimentalClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawExperimentalClient
        """
        return self._raw_client

    async def extended(
        self,
        *,
        latitude: float,
        longitude: float,
        timezone: typing.Optional[Timezone] = None,
        units: typing.Optional[Units] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HourlyWeatherResponse:
        """
        Get hourly weather forecast for a specific location and time

        Parameters
        ----------
        latitude : float

        longitude : float

        timezone : typing.Optional[Timezone]

        units : typing.Optional[Units]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HourlyWeatherResponse
            Successful Response

        Examples
        --------
        import asyncio

        from silurian import AsyncEarth

        client = AsyncEarth(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.weather.experimental.extended(
                latitude=47.6061,
                longitude=-122.3328,
            )


        asyncio.run(main())
        """
        response = await self._raw_client.extended(
            latitude=latitude, longitude=longitude, timezone=timezone, units=units, request_options=request_options
        )
        return response.data



# This file was auto-generated by Fern from our API Definition.

from ..core.pydantic_utilities import UniversalBaseModel
import typing
import typing_extensions
from ..core.serialization import FieldMetadata
from ..core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class GftusBaseUnits(UniversalBaseModel):
    elevation: str
    temperature: str
    humidity: typing.Optional[str] = None
    wind_speed: str
    wind_direction: typing.Optional[str] = None
    wind_speed_80_m: typing_extensions.Annotated[str, FieldMetadata(alias="wind_speed_80m")]
    wind_direction_80_m: typing_extensions.Annotated[
        typing.Optional[str], FieldMetadata(alias="wind_direction_80m")
    ] = None
    dewpoint_temperature: str
    feels_like_temperature: str
    pressure: str
    downward_solar_radiation: str
    precipitation_accumulation: str
    precipitation_probability: typing.Optional[str] = None
    cloud_cover: typing.Optional[str] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ..core.client_wrapper import SyncClientWrapper
import typing
import datetime as dt
from ..types.model_name import ModelName
from ..core.request_options import RequestOptions
from ..core.http_response import HttpResponse
from ..types.cyclone_forecast_response import CycloneForecastResponse
from ..core.datetime_utils import serialize_datetime
from ..core.pydantic_utilities import parse_obj_as
from ..errors.unprocessable_entity_error import UnprocessableEntityError
from ..types.http_validation_error import HttpValidationError
from json.decoder import JSONDecodeError
from ..core.api_error import ApiError
from ..types.feature_collection import FeatureCollection
from ..core.jsonable_encoder import jsonable_encoder
from ..core.client_wrapper import AsyncClientWrapper
from ..core.http_response import AsyncHttpResponse


class RawCycloneClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def query_forecasts(
        self,
        *,
        time: typing.Optional[dt.datetime] = None,
        min_storm_category: typing.Optional[int] = None,
        model: typing.Optional[ModelName] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[typing.List[CycloneForecastResponse]]:
        """
        Query the available cyclone forecasts for a particular time

        Parameters
        ----------
        time : typing.Optional[dt.datetime]
            *Default value: (current time) - Default time zone: UTC*

        min_storm_category : typing.Optional[int]

        model : typing.Optional[ModelName]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[typing.List[CycloneForecastResponse]]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            "cyclone/forecasts",
            method="GET",
            params={
                "time": serialize_datetime(time) if time is not None else None,
                "min_storm_category": min_storm_category,
                "model": model,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    typing.List[CycloneForecastResponse],
                    parse_obj_as(
                        type_=typing.List[CycloneForecastResponse],  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def get_forecast_track(
        self,
        storm_id: str,
        *,
        time: typing.Optional[dt.datetime] = None,
        model: typing.Optional[ModelName] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[FeatureCollection]:
        """
        Get cyclone tracks in GeoJSON (MF-GeoJSON) format

        Parameters
        ----------
        storm_id : str

        time : typing.Optional[dt.datetime]
            *Default value: (current time) - Default time zone: UTC*

        model : typing.Optional[ModelName]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[FeatureCollection]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            f"cyclone/forecasts/{jsonable_encoder(storm_id)}/track",
            method="GET",
            params={
                "time": serialize_datetime(time) if time is not None else None,
                "model": model,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    FeatureCollection,
                    parse_obj_as(
                        type_=FeatureCollection,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def get_forecast_cone(
        self,
        storm_id: str,
        *,
        time: typing.Optional[dt.datetime] = None,
        lead_time: typing.Optional[str] = None,
        smooth_cone: typing.Optional[bool] = None,
        model: typing.Optional[ModelName] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[FeatureCollection]:
        """
        Get cyclone forecast cone in GeoJSON format

        Parameters
        ----------
        storm_id : str

        time : typing.Optional[dt.datetime]
            *Default value: (current time) - Default time zone: UTC*

        lead_time : typing.Optional[str]

        smooth_cone : typing.Optional[bool]

        model : typing.Optional[ModelName]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[FeatureCollection]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            f"cyclone/forecasts/{jsonable_encoder(storm_id)}/cone",
            method="GET",
            params={
                "time": serialize_datetime(time) if time is not None else None,
                "lead_time": lead_time,
                "smooth_cone": smooth_cone,
                "model": model,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    FeatureCollection,
                    parse_obj_as(
                        type_=FeatureCollection,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)


class AsyncRawCycloneClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def query_forecasts(
        self,
        *,
        time: typing.Optional[dt.datetime] = None,
        min_storm_category: typing.Optional[int] = None,
        model: typing.Optional[ModelName] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[typing.List[CycloneForecastResponse]]:
        """
        Query the available cyclone forecasts for a particular time

        Parameters
        ----------
        time : typing.Optional[dt.datetime]
            *Default value: (current time) - Default time zone: UTC*

        min_storm_category : typing.Optional[int]

        model : typing.Optional[ModelName]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[typing.List[CycloneForecastResponse]]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            "cyclone/forecasts",
            method="GET",
            params={
                "time": serialize_datetime(time) if time is not None else None,
                "min_storm_category": min_storm_category,
                "model": model,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    typing.List[CycloneForecastResponse],
                    parse_obj_as(
                        type_=typing.List[CycloneForecastResponse],  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def get_forecast_track(
        self,
        storm_id: str,
        *,
        time: typing.Optional[dt.datetime] = None,
        model: typing.Optional[ModelName] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[FeatureCollection]:
        """
        Get cyclone tracks in GeoJSON (MF-GeoJSON) format

        Parameters
        ----------
        storm_id : str

        time : typing.Optional[dt.datetime]
            *Default value: (current time) - Default time zone: UTC*

        model : typing.Optional[ModelName]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[FeatureCollection]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"cyclone/forecasts/{jsonable_encoder(storm_id)}/track",
            method="GET",
            params={
                "time": serialize_datetime(time) if time is not None else None,
                "model": model,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    FeatureCollection,
                    parse_obj_as(
                        type_=FeatureCollection,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def get_forecast_cone(
        self,
        storm_id: str,
        *,
        time: typing.Optional[dt.datetime] = None,
        lead_time: typing.Optional[str] = None,
        smooth_cone: typing.Optional[bool] = None,
        model: typing.Optional[ModelName] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[FeatureCollection]:
        """
        Get cyclone forecast cone in GeoJSON format

        Parameters
        ----------
        storm_id : str

        time : typing.Optional[dt.datetime]
            *Default value: (current time) - Default time zone: UTC*

        lead_time : typing.Optional[str]

        smooth_cone : typing.Optional[bool]

        model : typing.Optional[ModelName]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[FeatureCollection]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"cyclone/forecasts/{jsonable_encoder(storm_id)}/cone",
            method="GET",
            params={
                "time": serialize_datetime(time) if time is not None else None,
                "lead_time": lead_time,
                "smooth_cone": smooth_cone,
                "model": model,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    FeatureCollection,
                    parse_obj_as(
                        type_=FeatureCollection,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)



# This file was auto-generated by Fern from our API Definition.

from ..core.pydantic_utilities import UniversalBaseModel
import typing
from .multi_line_string_coordinates_item_item import MultiLineStringCoordinatesItemItem
from ..core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class MultiLineString(UniversalBaseModel):
    """
    MultiLineString Model
    """

    bbox: typing.Optional[typing.List[typing.Optional[typing.Any]]] = None
    coordinates: typing.List[typing.List[MultiLineStringCoordinatesItemItem]]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ..core.pydantic_utilities import UniversalBaseModel
from .geo_location import GeoLocation
import datetime as dt
from ..core.pydantic_utilities import IS_PYDANTIC_V2
import typing
import pydantic


class CycloneForecastResponse(UniversalBaseModel):
    storm_id: str
    storm_name: str
    type: str
    category: int
    position: GeoLocation
    forecast_time: dt.datetime
    forecast_source_info: str
    last_updated: dt.datetime

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from .base_model import BaseModel
from .cyclone_forecast_response import CycloneForecastResponse
from .daily_conditions import DailyConditions
from .daily_weather_response import DailyWeatherResponse
from .daily_weather_response_units import DailyWeatherResponseUnits
from .feature import Feature
from .feature_collection import FeatureCollection
from .feature_geometry import (
    FeatureGeometry,
    FeatureGeometry_GeometryCollection,
    FeatureGeometry_LineString,
    FeatureGeometry_MultiLineString,
    FeatureGeometry_MultiPoint,
    FeatureGeometry_MultiPolygon,
    FeatureGeometry_Point,
    FeatureGeometry_Polygon,
)
from .feature_id import FeatureId
from .feature_properties import FeatureProperties
from .geo_location import GeoLocation
from .geometry_collection import GeometryCollection
from .geometry_collection_geometries_item import (
    GeometryCollectionGeometriesItem,
    GeometryCollectionGeometriesItem_GeometryCollection,
    GeometryCollectionGeometriesItem_LineString,
    GeometryCollectionGeometriesItem_MultiLineString,
    GeometryCollectionGeometriesItem_MultiPoint,
    GeometryCollectionGeometriesItem_MultiPolygon,
    GeometryCollectionGeometriesItem_Point,
    GeometryCollectionGeometriesItem_Polygon,
)
from .gftus_base_units import GftusBaseUnits
from .gftus_hourly_conditions import GftusHourlyConditions
from .gftus_hourly_weather_response import GftusHourlyWeatherResponse
from .hourly_conditions import HourlyConditions
from .hourly_weather_response import HourlyWeatherResponse
from .hourly_weather_response_units import HourlyWeatherResponseUnits
from .http_validation_error import HttpValidationError
from .imperial_units import ImperialUnits
from .line_string import LineString
from .line_string_coordinates_item import LineStringCoordinatesItem
from .metric_units import MetricUnits
from .model_name import ModelName
from .multi_line_string import MultiLineString
from .multi_line_string_coordinates_item_item import MultiLineStringCoordinatesItemItem
from .multi_point import MultiPoint
from .multi_point_coordinates_item import MultiPointCoordinatesItem
from .multi_polygon import MultiPolygon
from .multi_polygon_coordinates_item_item_item import MultiPolygonCoordinatesItemItemItem
from .point import Point
from .point_coordinates import PointCoordinates
from .polygon import Polygon
from .polygon_coordinates_item_item import PolygonCoordinatesItemItem
from .position_2_d import Position2D
from .position_3_d import Position3D
from .precipitation_type import PrecipitationType
from .timezone import Timezone
from .units import Units
from .validation_error import ValidationError
from .validation_error_loc_item import ValidationErrorLocItem
from .weather_code import WeatherCode

__all__ = [
    "BaseModel",
    "CycloneForecastResponse",
    "DailyConditions",
    "DailyWeatherResponse",
    "DailyWeatherResponseUnits",
    "Feature",
    "FeatureCollection",
    "FeatureGeometry",
    "FeatureGeometry_GeometryCollection",
    "FeatureGeometry_LineString",
    "FeatureGeometry_MultiLineString",
    "FeatureGeometry_MultiPoint",
    "FeatureGeometry_MultiPolygon",
    "FeatureGeometry_Point",
    "FeatureGeometry_Polygon",
    "FeatureId",
    "FeatureProperties",
    "GeoLocation",
    "GeometryCollection",
    "GeometryCollectionGeometriesItem",
    "GeometryCollectionGeometriesItem_GeometryCollection",
    "GeometryCollectionGeometriesItem_LineString",
    "GeometryCollectionGeometriesItem_MultiLineString",
    "GeometryCollectionGeometriesItem_MultiPoint",
    "GeometryCollectionGeometriesItem_MultiPolygon",
    "GeometryCollectionGeometriesItem_Point",
    "GeometryCollectionGeometriesItem_Polygon",
    "GftusBaseUnits",
    "GftusHourlyConditions",
    "GftusHourlyWeatherResponse",
    "HourlyConditions",
    "HourlyWeatherResponse",
    "HourlyWeatherResponseUnits",
    "HttpValidationError",
    "ImperialUnits",
    "LineString",
    "LineStringCoordinatesItem",
    "MetricUnits",
    "ModelName",
    "MultiLineString",
    "MultiLineStringCoordinatesItemItem",
    "MultiPoint",
    "MultiPointCoordinatesItem",
    "MultiPolygon",
    "MultiPolygonCoordinatesItemItemItem",
    "Point",
    "PointCoordinates",
    "Polygon",
    "PolygonCoordinatesItemItem",
    "Position2D",
    "Position3D",
    "PrecipitationType",
    "Timezone",
    "Units",
    "ValidationError",
    "ValidationErrorLocItem",
    "WeatherCode",
]



# This file was auto-generated by Fern from our API Definition.

from ..core.client_wrapper import SyncClientWrapper
from .raw_client import RawWeatherClient
from .forecast.client import ForecastClient
from .experimental.client import ExperimentalClient
from .past.client import PastClient
from ..core.client_wrapper import AsyncClientWrapper
from .raw_client import AsyncRawWeatherClient
from .forecast.client import AsyncForecastClient
from .experimental.client import AsyncExperimentalClient
from .past.client import AsyncPastClient


class WeatherClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawWeatherClient(client_wrapper=client_wrapper)
        self.forecast = ForecastClient(client_wrapper=client_wrapper)

        self.experimental = ExperimentalClient(client_wrapper=client_wrapper)

        self.past = PastClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawWeatherClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawWeatherClient
        """
        return self._raw_client


class AsyncWeatherClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawWeatherClient(client_wrapper=client_wrapper)
        self.forecast = AsyncForecastClient(client_wrapper=client_wrapper)

        self.experimental = AsyncExperimentalClient(client_wrapper=client_wrapper)

        self.past = AsyncPastClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawWeatherClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawWeatherClient
        """
        return self._raw_client
